<template>
    <view>
        <view class="page">
            <up-sticky bgColor="#fff">
                <view class="card-footer">
                    <view class="user-info">
                        <up-avatar :src="user.avatar" size="60rpx" shape="circle" />
                        <view class="user-text">
                            <text class="nickname">{{ user.username }}</text>
                        </view>
                    </view>
                    <view class="opera-info">
                        <button class="custom-btn">关注</button>
                        <up-icon name="/static/common/share2.png" size="40rpx" color="#999" />
                    </view>
                </view>
            </up-sticky>

            <scroll-view class="content" scroll-y>
                <view class="swiper-container">
                    <swiper :current="currentNum" @change="onSwiperChange" circular :autoplay="false"
                        class="custom-swiper">
                        <swiper-item v-for="(item, index) in filmPictureList" :key="index" class="swiper-item">
                            <image :src="item" mode="aspectFill" class="swiper-image" @tap="previewImage(index)" />
                        </swiper-item>
                    </swiper>
                    <view class="indicator-num">
                        <text class="indicator-num__text">{{ currentNum + 1 }}/{{ filmPictureList.length }}</text>
                    </view>
                </view>

                <view class="article-content">
                    <view class="title content-item">
                        <text>{{ filmInfo.coverTitle }}</text>
                    </view>

                    <view class="content-item">
                        <!-- <rich-text :nodes="filmInfo.filmContent" /> -->
                        <up-parse :content="filmInfo.filmContent"></up-parse>
                    </view>
                    <view class="annotation content-item">
                        <text>{{ formatRelativeTime(filmInfo.createTime) }} 美国</text>
                    </view>
                </view>

                <up-line></up-line>

                <view class="comment">
                    <view class="writer-view" @click="showCommentLayer">
                        <up-icon name="chat-fill" size="60rpx" />
                        <view class="comment-operation">
                            <up-text size="12px" text="说点什么......" margin="0 0 0 20rpx" color="#B9B9B9" />
                        </view>
                    </view>

                    <!-- 示例评论项，comment-item 可替换为实际组件 -->
                    <comment-item avatar="https://img.yzcdn.cn/vant/cat.jpeg" nickname="图墙精选" :isAuthor="true"
                        content="如果路线里全是常规景区..." :images="urls2" date="2天前" address="湖北" :likes="30"
                        @reply="showCommentLayer" />
                </view>
            </scroll-view>

            <!-- 固定底部输入框 -->
            <view class="comment-box">
                <view class="input-row">
                    <view class="comment-input" @click="showCommentLayer">
                        <up-text size="12px" text="说点什么......" margin="0 0 0 20rpx" color="#B9B9B9" />
                    </view>
                    <up-icon name="heart" size="60rpx" color="#B9B9B9" label="11" />
                    <up-icon name="star" size="60rpx" color="#B9B9B9" label="22" />
                    <up-icon name="chat" size="60rpx" color="#B9B9B9" label="33" />
                </view>
            </view>
        </view>

        <comment-popup v-model="commentShow" />
    </view>
</template>

<script setup lang="ts">

import { ref, reactive } from 'vue'
import { onShow, onPullDownRefresh, onReachBottom } from '@dcloudio/uni-app'
import { onLoad } from '@dcloudio/uni-app'
import { useGlobal } from '@/composables/useGlobal'
const { $http, $message, $store } = useGlobal()

import { FilmInfo,FilmPicture } from '@/types/index'
import { formatRelativeTime } from '@/utils/time'

// Swiper 当前页
const currentNum = ref(0)
const commentShow = ref(false)

const user = reactive({
    id: 3,
    username: '图墙精选',
    avatar: 'https://img.yzcdn.cn/vant/cat.jpeg'
})

const urls2 = ref<string[]>([
    'https://img.yzcdn.cn/vant/cat.jpeg'
])

const desc = ref(`
  😭……
  刚从新疆旅游回来，真的踩了好多坑！！...<br/>
  #新疆是个好地方 #新疆旅行攻略...
  `)

onLoad((options:any) => {
    const theme = uni.getStorageSync('theme') || 'light'
    console.log('theme:', theme)

    // 获取传递来的参数
    console.log('传入参数:', options)

    // 示例：你传过来的参数可能是这样 ?id=123&type=test
    const id = options.id
    const type = options.type
    console.log('id:', id, 'type:', type)
    if(id){
        getFilmInfoById(id)
    }
})

const onSwiperChange = (e: any) => {
    currentNum.value = e.detail.current
}

const previewImage = (index: number) => {
    uni.previewImage({
        current: filmPictureList.value[index],
        urls: filmPictureList.value
    })
}

const showCommentLayer = () => {
    commentShow.value = true
}

onShow(() => {
    
});

const filmInfo = ref<FilmInfo>()

const filmPictureList = ref<string[]>([])
const getFilmInfoById  = async (id:String)=>{ 
    const {
    code, data
  } = await $http.request('get', '/api/filmWorks/list/view', {
    params: {
      id: id
    }
  })
  if (code == 0) {
    filmInfo.value=data
    console.log("详情",filmInfo.value)
    if(data && data.filmPictures){
        // 只获取里面的url
        // filmPictureList.value=JSON.parse(data.filmPictures) as Array<FilmPicture>
        const tmpPicture = JSON.parse(data.filmPictures) as FilmPicture[]
        filmPictureList.value = tmpPicture.map(item => item.url)
        // 如果 filmPictureList.value是空的情况下，则把封面放入到图片列表中
        // debugger;
        if (filmPictureList.value.length === 0) {
          filmPictureList.value.push(data.coverUrl)
        }
    }else{
        if (filmPictureList.value.length === 0) {
          filmPictureList.value.push(data.coverUrl)
        }
    }
    console.log("图片列表",filmPictureList.value)
  } else {
    $message.showToast('系统异常，无法获取数据')
    return null;
  }
}
</script>


<style scoped>
.page {
    display: flex;
    flex-direction: column;
    height: 100vh;
    background-color: #fff;
}

.swiper-container {
    position: relative;
    width: 100%;
    height: 500rpx;
}

.custom-swiper {
    width: 100%;
    height: 100%;
}

.swiper-item {
    display: flex;
    justify-content: center;
    align-items: center;
    height: 100%;

}

.swiper-image {
    width: 100%;
    height: 100%;
    object-fit: cover;
}

.indicator-num {
    position: absolute;
    top: 20rpx;
    right: 20rpx;
    padding: 4rpx 12rpx;
    background-color: rgba(0, 0, 0, 0.4);
    border-radius: 20rpx;
}

.indicator-num__text {
    color: #fff;
    font-size: 24rpx;
}
</style>

<style lang="scss" scoped>
.card-footer {
    display: flex;
    justify-content: space-between;
    align-items: center;
    padding: 10rpx;
    background-color: #FFFFFF;
}

.user-info {
    display: flex;
    align-items: center;

    .user-text {
        font-size: 30rpx;
        line-height: 30px;
        margin-left: 10rpx;

        .nickname {
            font-weight: bold;
            display: block;
            color: #646464;
            letter-spacing: 2rpx;
        }

        .date {
            font-size: 12px;
            color: #aaa;
            margin-top: 10rpx;
        }
    }
}

.opera-info {
    display: flex;
    align-items: center;

    text {
        margin-left: 10rpx;
        font-size: 12px;
    }
}

.content {
    .annotation {
        margin-top: 10rpx;
        font-size: 20rpx;
        color: #646464;
    }
}

.comment {
    margin: 10rpx;

    // border-top: 1rpx solid #EBEBEB;
    .writer-view {
        display: flex;
        justify-content: space-between;
        align-items: center;
        margin-bottom: 30rpx;

        .comment-operation {
            font-size: 18rpx;
            background-color: #F4F4F6;
            height: 30px;
            line-height: 30px;
            border-radius: 20px;
            width: 92%;
        }
    }


}

.article-content {
    padding: 10rpx;
    font-size: 32rpx;
    letter-spacing: 1rpx;

    .title {
        font-size: 36rpx;
        font-weight: bold;
    }

    .content-item {
        margin-bottom: 20rpx;
    }
}


.comment-box {
    position: fixed;
    bottom: 0;
    left: 0;
    right: 0;
    padding: 20rpx 20rpx;
    background-color: #fff;
    box-shadow: 0 -2rpx 10rpx rgba(0, 0, 0, 0.05);
    z-index: 999;
    height: 100rpx;

    .input-row {
        display: flex;
        align-items: center;
        justify-content: space-between;
        height: 80%;

        .comment-input {
            width: 300rpx;
            background-color: #F4F4F6;
            border-radius: 50rpx;
            height: 60rpx;
            display: flex;
            align-items: center;
        }
    }

    .flex-input {
        flex: 1;
        margin-right: 10rpx;
    }
}

.comment-popup {
    margin: 20rpx;

    .comment-btn-view {
        margin-top: 20rpx;
        display: flex;
        justify-content: space-between;
    }

    .comment-btn-icon {
        display: flex;
    }

    .comment-btn {}
}
</style>


<style scoped>
.custom-btn {
    /* background-color: #ff4d4f; */
    margin: 0 10rpx;
    /* 自定义背景色 */
    color: #ff4d4f;
    /* 字体颜色 */
    font-size: 20rpx;
    /* 字体大小 */
    border-radius: 50rpx;
    /* 圆角 */
    padding: 10rpx 20rpx;
    /* 内边距 */
    border: 1px solid #ff4d4f;
    /* 去除边框 */
    line-height: 1;
}

.custom-btn::after {
    border: none;
    /* 去除点击阴影边框 */
}
</style>

<style scoped>
.page {
    height: 100vh;
    display: flex;
    flex-direction: column;
}

.content {
    flex: 1;
    overflow-y: auto;
    padding-bottom: 180rpx;
    /* 留出评论区高度，避免遮挡 */
}
</style>